<?php
/**
 * * @package               Joomla
* @subpackage    com_ajofields
* @version            0.9.0
* @release            2020-02-26 06:30:36
* @copyright        Copyright (C) 2020 Danny Buytaert. All rights reserved. All rights reserved.
* @author             Danny Buytaert
* @license             GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

/**
 * Ajofields helper.
 *
 * @package     A package name
 * @since       1.0
 */
class AjofieldsHelper
{
    /**
     * Render submenu.
     *
     * @param string $vName The name of the current view.
     *
     * @return  void.
     *
     * @since   1.0
     */
    public function addSubmenu($vName)
    {

        // Load 'views' in menu
        $results=self::getAllProfiles();

        JHtmlSidebar::addEntry('<b>' . JText::_('COM_AJOFIELDS_TITLE_MY_COLUMN_SETS') . '</b>');
        foreach ($results as $result) {

            JHtmlSidebar::addEntry('<span class="' . $result->icon . '"> </span>' . $result->title, 'index.php?option=com_ajofields&task=items.setview&id=' . (int)$result->id, $vName == $result->id);

        }


        JHtmlSidebar::addEntry('<br/><hr><b>' . JText::_('JADMINISTRATION') . '</b>');
        JHtmlSidebar::addEntry('<span class="icon-dashboard"> </span>' . JText::_('COM_AJOFIELDS_TITLE_DASHBOARD'), 'index.php?option=com_ajofields&view=dashboard', $vName == 'dashboard');

        JHtmlSidebar::addEntry('<span class="icon-list"> </span>' . JText::_('COM_AJOFIELDS_COLUMN_SETS'), 'index.php?option=com_ajofields&view=profiles', $vName == 'profiles');


    }
    public function getAllProfiles()
    {
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $query->select('*');
        $query->from($db->quoteName('#__ajofields_profiles'));
        $query->where($db->quoteName('state') . ' =1 ');
        $query->order('ordering ASC');
        $db->setQuery($query);
        $results = $db->loadObjectList();
        return $results;

    }

    public function getFields($context)
    {
//if isset
        $file = str_replace('.', '_', $context) . '.json';
        $url = JPATH_COMPONENT_ADMINISTRATOR . '/data/' . $file;
        $content = file_get_contents($url);
        $items = json_decode($content);
        return $items;
    }


    public function getProfile()
    {
        $session = JFactory::getSession();
        $ajoProfile = $session->get('ajoProfile', '0');
        $context = $session->get('ajoProfileContext');

        if ($ajoProfile > 0) {

            $model = JModelLegacy::getInstance('profile', 'AjofieldsModel');
            $profile = $model->getItem($ajoProfile);
            $items = json_decode($profile->list);
            $fields = self::getFields($context);


            $fieldsArray = array();
            foreach ($fields->fields as $field) {

                $fieldsArray[$field->field]['jtext'] = $field->jtext;
                $fieldsArray[$field->field]['sort'] = $field->sort;
                $fieldsArray[$field->field]['tab'] = $field->tab;
            }


            foreach ($items as $item) {

                if (isset($fieldsArray[$item->fields])) {
                    $item->jtext = $fieldsArray[$item->fields]['jtext'];
                    $item->sort = $fieldsArray[$item->fields]['sort'];
                    $item->tab = $fieldsArray[$item->fields]['tab'];

                } else {

                    $item->jtext = $item->fields;
                    $item->sort = '';
                    $item->tab = 'custom';


                }


            }


            return $items;


        }


    }


    /**
     * Gets a list of the actions that can be performed.
     *
     * @return    JObject
     *
     * @since    1.6
     */
    public static function getActions()
    {
        $user = JFactory::getUser();
        $result = new JObject;

        $assetName = 'com_ajofields';

        $actions = array(
            'core.admin', 'core.manage', 'core.create', 'core.edit', 'core.edit.own', 'core.edit.state', 'core.delete'
        );

        foreach ($actions as $action) {
            $result->set($action, $user->authorise($action, $assetName));
        }

        return $result;
    }



    public static function getVersion()
    {
        $folder = JPATH_ADMINISTRATOR . '/' . 'components/com_ajofields';
        if (JFolder::exists($folder)) {
            $xmlFilesInDir = JFolder::files($folder, '.xml$');
        } else {
            $folder = JPATH_SITE . '/components/com_ajofields';
            if (JFolder::exists($folder)) {
                $xmlFilesInDir = JFolder::files($folder, '.xml$');
            } else {
                $xmlFilesInDir = null;
            }
        }
        $xml_items = array();
        if (count($xmlFilesInDir)) {
            foreach ($xmlFilesInDir as $xmlfile) {
                if ($data = \JInstaller::parseXMLInstallFile($folder . '/' . $xmlfile)) {
                    foreach ($data as $key => $value) {
                        $xml_items[$key] = $value;
                    }
                }
            }
        }
        if (isset($xml_items['version']) && $xml_items['version'] != '') {
            return $xml_items['version'];
        } else {
            return '';
        }
    }

}
