<?php
/**
 * * @package               Joomla
* @subpackage    com_ajofields
* @version            0.9.0
* @release            2020-02-26 06:30:36
* @copyright        Copyright (C) 2020 Danny Buytaert. All rights reserved. All rights reserved.
* @author             Danny Buytaert
* @license             GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

/**
 * View class for a list of articles.
 *
 * @since  1.6
 */

require_once JPATH_ADMINISTRATOR . '/components/com_content/helpers/content.php';

class AjofieldsViewItems extends JViewLegacy
{
    /**
     * The item authors
     *
     * @var  stdClass
     *
     * @deprecated  4.0  To be removed with Hathor
     */
    protected $authors;

    /**
     * An array of items
     *
     * @var  array
     */
    protected $items;

    /**
     * The pagination object
     *
     * @var  JPagination
     */
    protected $pagination;

    /**
     * The model state
     *
     * @var  object
     */
    protected $state;

    /**
     * Form object for search filters
     *
     * @var  JForm
     */
    public $filterForm;

    /**
     * The active search filters
     *
     * @var  array
     */
    public $activeFilters;

    /**
     * The sidebar markup
     *
     * @var  string
     */
    protected $sidebar;

    /**
     * Display the view
     *
     * @param string $tpl The name of the template file to parse; automatically searches through the template paths.
     *
     * @return  mixed  A string if successful, otherwise an Error object.
     */
    public function display($tpl = null)
    {

        $app = JFactory::getApplication();
        $this->params = JComponentHelper::getParams('com_ajofields');

        $this->helper = new AjofieldsHelper;



        $session = JFactory::getSession();

        $ajoProfile = $session->get('ajoProfile');

        if ($ajoProfile) {


            $this->context = $session->get('ajoProfileContext');
            $this->ajoitems = $this->helper->getProfile();


            $this->total = $this->get('Total');

            $this->items = $this->get('Items');
            $this->pagination = $this->get('Pagination');
            $this->state = $this->get('State');
            $this->authors = $this->get('Authors');
            $this->filterForm = $this->get('FilterForm');
            $this->activeFilters = $this->get('ActiveFilters');
            $this->vote = JPluginHelper::isEnabled('content', 'vote');


            // Check for errors.
            if (count($errors = $this->get('Errors'))) {
                throw new Exception(implode("\n", $errors), 500);
            }


            $com = explode('.', $this->context);

            $lang = JFactory::getLanguage();
            $extension = $com[0];
            $base_dir = JPATH_ADMINISTRATOR;
            $lang->load($extension, $base_dir);

            // Show the sidebar
            $this->helper = new AjofieldsHelper;
            $this->helper->addSubmenu($ajoProfile);


            $this->toolbar();

            $this->sidebar = JHtmlSidebar::render();

            return parent::display($tpl);
        } else {
            $app = JFactory::getApplication();

            $app->redirect('index.php?option=com_ajofields&view=profiles');

        }
    }

    /**
     * Add the page title and toolbar.
     *
     * @return  void
     *
     * @since   1.6
     */
    protected function toolbar()
    {

        $session = JFactory::getSession();



        $icon = substr($session->get('ajoProfileIcon'), 5);
        JToolbarHelper::title($session->get('ajoProfileTitle'), $icon);


    }

    /**
     * Returns an array of fields the table can be sorted by
     *
     * @return  array  Array containing the field name to sort by as the key and display text as value
     *
     * @since   3.0
     */
    protected function getSortFields()
    {


        //create filter fields
        $filterfields = array();
        foreach ($this->ajoitems as $sort) {
            $filterfields[$sort->sorting] = JText::_($sort->language);

        }


        return $filterfields;
    }
}
