<?php
/**
 * * @package               Joomla
* @subpackage    com_ajofields
* @version            0.9.0
* @release            2020-02-26 06:30:36
* @copyright        Copyright (C) 2020 Danny Buytaert. All rights reserved. All rights reserved.
* @author             Danny Buytaert
* @license             GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

jimport('joomla.application.component.view');

/**
 * View to edit
 *
 * @since  1.6
 */
class AjofieldsViewProfile extends JViewLegacy
{
    protected $state;

    protected $item;

    protected $form;

    /**
     * Display the view
     *
     * @param string $tpl Template name
     *
     * @return void
     *
     * @throws Exception
     */
    public function display($tpl = null)
    {
        $this->state = $this->get('State');
        $this->item = $this->get('Item');
        $this->form = $this->get('Form');

        // Check for errors.
        if (count($errors = $this->get('Errors'))) {
            throw new Exception(implode("\n", $errors));
        }
        $this->helper = new AjofieldsHelper;


        if ($this->item->context) {

            $session = JFactory::getSession();


            $session->set('ajoProfileContext', $this->item->context);

            $split = explode('.', $this->item->context);

            $lang = JFactory::getLanguage();
            $extension = $split[0];
            $base_dir = JPATH_ADMINISTRATOR;
            $lang->load($extension, $base_dir);
        }

        $this->addToolbar();
        parent::display($tpl);
    }

    /**
     * Add the page title and toolbar.
     *
     * @return void
     *
     * @throws Exception
     */
    protected function addToolbar()
    {
        JFactory::getApplication()->input->set('hidemainmenu', true);

        $user = JFactory::getUser();


        if (isset($this->item->checked_out)) {
            $checkedOut = !($this->item->checked_out == 0 || $this->item->checked_out == $user->get('id'));
        } else {
            $checkedOut = false;
        }

        $canDo = AjofieldsHelper::getActions();

        if (empty($this->item->id)) {
            JToolBarHelper::apply('profile.apply', 'JTOOLBAR_APPLY');
            JToolBarHelper::cancel('profile.cancel', 'JTOOLBAR_CANCEL');
            JToolBarHelper::title(JText::_('COM_AJOFIELDS_NEW_COLUMN_SET'), 'file');
        } else {
            JToolBarHelper::title(JText::_('COM_AJOFIELDS_EDIT_COLUMN_SET'), 'file-2');


            // If not checked out, can save the item.
            if (!$checkedOut && ($canDo->get('core.edit') || ($canDo->get('core.create')))) {
                JToolBarHelper::apply('profile.apply', 'JTOOLBAR_APPLY');
                JToolBarHelper::save('profile.save', 'JTOOLBAR_SAVE');
            }

            if ($canDo->get('core.create')) {
                JToolbarHelper::save2copy('profile.save2copy');
            }

            JToolBarHelper::cancel('profile.cancel', 'JTOOLBAR_CLOSE');

        }
    }
}
