<?php
/**
 * * @package               Joomla
* @subpackage    com_ajofields
* @version            0.9.0
* @release            2020-02-26 06:30:36
* @copyright        Copyright (C) 2020 Danny Buytaert. All rights reserved. All rights reserved.
* @author             Danny Buytaert
* @license             GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;
jimport('joomla.application.component.view');

/**
 * View class for a list of Ajofields.
 *
 * @since  1.6
 */
class AjofieldsViewProfiles extends JViewLegacy
{
	protected $items;

	protected $pagination;

	protected $state;

	/**
	 * Ajofields helper
	 *
	 * @var    AjofieldsHelper
	 * @since  1.0
	 */
	protected $helper;

	/**
	 * The sidebar to show
	 *
	 * @var    string
	 * @since  1.0
	 */
	protected $sidebar = '';

	/**
	 * Display the view
	 *
	 * @param   string  $tpl  Template name
	 *
	 * @return void
	 *
	 * @throws Exception
	 */
	public function display($tpl = null)
	{
		$this->state = $this->get('State');
		$this->items = $this->get('Items');
		$this->pagination = $this->get('Pagination');
		$this->total = $this->get('Total');
		$this->filterForm = $this->getModel()->getFilterForm();
		$this->activeFilters = $this->getModel()->getActiveFilters();
		$this->canDo         = JHelperContent::getActions('com_ajofields');
		// Check for errors.
		if (count($errors = $this->get('Errors')))
		{
			throw new Exception(implode("\n", $errors));
		}



		// Show the sidebar
		$this->helper = new AjofieldsHelper;
		$this->helper->addSubmenu('profiles');




		$this->toolbar();

		$this->sidebar = JHtmlSidebar::render();
		parent::display($tpl);
	}

	/**
	 * Displays a toolbar for a specific page.
	 *
	 * @return  void.
	 *
	 * @since   1.0
	 */
	private function toolbar()
	{
		JToolBarHelper::title(JText::_('COM_AJOFIELDS').' - '.JText::_('COM_AJOFIELDS_COLUMN_SETS'), 'list');
		$canDo = $this->canDo;


		// Options button.
		if (JFactory::getUser()->authorise('core.admin', 'com_ajofields'))
		{
			JToolBarHelper::preferences('com_ajofields');
		}

		// Check if the form exists before showing the add/edit buttons
		$formPath = JPATH_COMPONENT_ADMINISTRATOR . '/views/profile';

		if (file_exists($formPath))
		{

			if ($canDo->get('core.create'))
			{
				JToolbarHelper::addNew('profile.add');
			}

			if ($canDo->get('core.edit'))
			{
				JToolbarHelper::editList('profile.edit');
			}

		}


		if ($canDo->get('core.edit.state'))
		{
			if ($this->state->get('filter.published') != 2)
			{
				JToolbarHelper::publish('profiles.publish', 'JTOOLBAR_PUBLISH', true);
				JToolbarHelper::unpublish('profiles.unpublish', 'JTOOLBAR_UNPUBLISH', true);
			}

			if ($this->state->get('filter.published') != -1)
			{
				if ($this->state->get('filter.published') != 2)
				{
					JToolbarHelper::archiveList('profiles.archive');
				}
				elseif ($this->state->get('filter.published') == 2)
				{
					JToolbarHelper::unarchiveList('profiles.publish');
				}
			}
		}


		if ($this->state->get('filter.state') == -2 && $canDo->get('core.delete'))
		{
			JToolbarHelper::deleteList('JGLOBAL_CONFIRM_DELETE', 'profiles.delete', 'JTOOLBAR_EMPTY_TRASH');
		}
		elseif ($canDo->get('core.edit.state'))
		{
			JToolbarHelper::trash('profiles.trash');
		}



		if ($canDo->get('core.edit.state'))
		{
			JToolbarHelper::checkin('profiles.checkin');
		}
		JToolBarHelper::divider();


	}

}
